@@ -48,6 +48,7 @@ def get_client():
     return client
 
 def check_for_updates():
+    print("[debug] check_for_updates() was called")
     package = "lambda-cloud-cli"
     cache_dir = UPDATE_CACHE_FILE.parent
     cache_dir.mkdir(parents=True, exist_ok=True)
@@ -65,8 +66,12 @@ def check_for_updates():
         if installed != latest:
             typer.secho(f"📢 A new version is available: {installed} → {latest}", fg=typer.colors.YELLOW)
             typer.echo("👉 Run `lambda-cli self-update` to upgrade.\n")
-    except Exception:
-        pass  # Silent fail
+    except Exception as e:
+        print(f"[debug] update check failed: {e}")
+        pass
+
+
+    UPDATE_CACHE_FILE.touch()
 
 # ─────────────────────────────────────────────
 # 🚀 CLI Commands
@@ -257,13 +262,25 @@ def self_update(yes: bool = typer.Option(False, "--yes", help="Skip confirmation
     """Upgrade lambda-cloud-cli to the latest version from PyPI"""
     package = "lambda-cloud-cli"
 
+    def get_latest_version_from_pypi(package, retries=3, delay=5):
+        url = f"https://pypi.org/pypi/{package}/json"
+        for attempt in range(retries):
+            try:
+                response = requests.get(url, timeout=5)
+                return response.json()["info"]["version"]
+            except Exception as e:
+                if attempt < retries - 1:
+                    time.sleep(delay)
+                else:
+                    raise e
+
     try:
         installed = pkg_resources.get_distribution(package).version
     except pkg_resources.DistributionNotFound:
         installed = None
 
     try:
-        latest = requests.get(f"https://pypi.org/pypi/{package}/json", timeout=5).json()["info"]["version"]
+        latest = get_latest_version_from_pypi(package)
     except Exception:
         typer.echo("❌ Could not fetch latest version info from PyPI.")
         raise typer.Exit(code=1)
